﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
//using System.Threading.Tasks;
using System.Windows.Forms;
using Phidget22;
using Phidget22.Events;
using Phidget22.ExampleUtils;

namespace HumiditySensor_Example {
	public partial class Form1 : Form {
		CommandLineOpen open;
        formCleaner cleaner;
        HumiditySensor humidity = null;
		private ErrorEventBox errorBox;

		public Form1() {
			open = new CommandLineOpen(this);
            cleaner = new formCleaner(this);
            InitializeComponent();
		}

		public Form1(String[] commandLine) {
			open = new CommandLineOpen(this);
            cleaner = new formCleaner(this);
            open.commandLine = commandLine;
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e) {
			this.Size = this.MinimumSize;

			
			errorBox = new ErrorEventBox(this);
			humidity = new HumiditySensor();

			humidity.Attach += humidity_attach;
			humidity.Detach += humidity_detach;
			humidity.Error += humidity_error;
			humidity.HumidityChange += humidity_change;

			open.openCmdLine(humidity);
		}

		private void Form1_FormClosing(object sender, FormClosingEventArgs e) {
			humidity.Close();
		}

		void humidity_attach(object sender, Phidget22.Events.AttachEventArgs e) {
			phidgetInfoBox1.FillPhidgetInfo((Phidget)sender);

			HumiditySensor attachedDevice = (HumiditySensor)sender;

			try {
				attachedDevice.DataInterval = attachedDevice.MinDataInterval;

				attachedDevice.HumidityChangeTrigger = attachedDevice.MinHumidityChangeTrigger;

				dataIntervalTrk.Unit = "ms";
				dataIntervalTrk.minTxt = attachedDevice.MinDataInterval.ToString();
				dataIntervalTrk.Minimum = attachedDevice.MinDataInterval;
				dataIntervalTrk.maxTxt = attachedDevice.MaxDataInterval.ToString();
				dataIntervalTrk.Maximum = attachedDevice.MaxDataInterval;
				dataIntervalTrk.Value = attachedDevice.MinDataInterval;
				dataIntervalTrk.trkText = attachedDevice.DataInterval.ToString();

				changeTriggerTrk.Unit = "%";
				changeTriggerTrk.minTxt = attachedDevice.MinHumidityChangeTrigger.ToString();
				changeTriggerTrk.Minimum = attachedDevice.MinHumidityChangeTrigger;
				changeTriggerTrk.Maximum = attachedDevice.MaxHumidityChangeTrigger;
				changeTriggerTrk.maxTxt = attachedDevice.MaxHumidityChangeTrigger.ToString();
				changeTriggerTrk.Value = 0;
				changeTriggerTrk.trkText = attachedDevice.HumidityChangeTrigger.ToString();
				changeTriggerTrk.trkText = attachedDevice.HumidityChangeTrigger.ToString("F0");

			} catch (PhidgetException ex) { errorBox.addMessage("Error initializing device: " + ex.Message); }

			settingsBox.Visible = true;
			outputBox.Visible = true;
		}

		void humidity_detach(object sender, Phidget22.Events.DetachEventArgs e) {
			phidgetInfoBox1.Clear();
            cleaner.clean();

            settingsBox.Visible = false;
			outputBox.Visible = false;
		}

		void humidity_error(object sender, Phidget22.Events.ErrorEventArgs e) {
			errorBox.addMessage(e.Description);
		}

		void humidity_change(object sender, Phidget22.Events.HumiditySensorHumidityChangeEventArgs e) {
			try {
				humTxt.Text = Math.Round(e.Humidity, 4).ToString() + "%";
			} catch (PhidgetException ex) { errorBox.addMessage("Error reading humidity: " + ex.Message); }
		}

		private void dataIntervalTrk_Scroll(object sender, EventArgs e) {
			if (MouseButtons != MouseButtons.Left) {
				try {
					humidity.DataInterval = (int)dataIntervalTrk.Value;
				} catch (Exception ex) {
					errorBox.addMessage("Error setting data interval: " + ex.Message);
				}
			}
		}

		private void dataIntervalTrk_MouseUp(object sender, MouseEventArgs e) {
			try {
				humidity.DataInterval = (int)dataIntervalTrk.Value;
			} catch (Exception ex) {
				errorBox.addMessage("Error setting data interval: " + ex.Message);
			}
		}

		private void changeTriggertrk_Scroll(object sender, EventArgs e) {
			if (MouseButtons != MouseButtons.Left) {
				try {
					humidity.HumidityChangeTrigger = changeTriggerTrk.Value;
				} catch (Exception ex) {
					errorBox.addMessage("Error setting change trigger: " + ex.Message);
				}
			}
		}

		private void changeTriggertrk_MouseUp(object sender, MouseEventArgs e) {
			try {
				humidity.HumidityChangeTrigger = changeTriggerTrk.Value;
			} catch (Exception ex) {
				errorBox.addMessage("Error setting change trigger: " + ex.Message);
			}
		}
	}
}
